==> vardoc-8.x-2.0-core.tar.gz: vardoc-8.x-2.0/profiles/vardoc/profiles/varbase/README.md <==
[![Build Status](https://travis-ci.org/Vardot/varbase.svg?branch=8.x-5.0)](https://travis-ci.org/Vardot/varbase/builds/428048604) Varbase 8.5.0

[![](https://www.drupal.org/files/styles/grid-3/public/project-images/Medium-Logo%20Color%20with%20padding.png)](https://www.drupal.org/project/varbase)

## Varbase: The Ultimate Drupal 8 CMS Starter Kit (Bootstrap Ready)

The powerful Drupal distribution for faster development, with editor experience
in mind. Brought to you by [Vardot](https://www.vardot.com/).

Varbase is an enhanced Drupal distribution with a lot of necessities.
Necessities are all the modules, features, configurations that we include
in every project.


## It's made with the following benefits in mind:

* Speeds up development.
* Offers standardized configuration and best-practices.
* Comes with a lot of needed functionalities/modules for every-day Drupal site.
* [Tested, tested, and tested.](https://travis-ci.org/Vardot/varbase/builds)

Starting a new project? Consider Varbase for Drupal 8.
Installing Varbase 8.x-5.x comes with several extra automated installation
steps, to take full advantage of Varbase, other than the Drupal 8 installation
instructions.

# Install with Composer

To install the most recent stable release of Varbase 8.5.x run this command:
```
composer create-project Vardot/varbase-project:^8.5.0 PROJECT_DIR_NAME --no-dev --no-interaction
```

To install the dev version of Varbase 8.5.x run this command:
```
composer create-project vardot/varbase-project:8.5.x-dev PROJECT_DIR_NAME --stability dev --no-interaction
```

## [Create a new Vartheme sub theme for a project](https://github.com/Vardot/varbase/tree/8.x-5.x/scripts/README.md)

## [Automated Functional Testing](https://github.com/Vardot/varbase/blob/8.x-5.x/tests/README.md)

## [Varbase Gherkin features](https://github.com/Vardot/varbase/blob/8.x-5.x/tests/features/varbase/README.md)

## [Varbase 8.5.x Developer Guide](https://docs.varbase.vardot.com)

## [CHANGELOG for Varbase](https://github.com/Vardot/varbase/blob/8.x-5.x/CHANGELOG.md)

## [General instructions on how to update Varbase](https://github.com/Vardot/varbase/blob/8.x-5.x/UPDATE.md)

==> vardoc-8.x-2.2-core.tar.gz: vardoc-8.x-2.2/profiles/vardoc/profiles/varbase/README.md <==
[![Build Status](https://travis-ci.org/Vardot/varbase.svg?branch=8.x-5.4)](https://travis-ci.org/Vardot/varbase/builds/452481243) Varbase 8.5.4

[![](https://www.drupal.org/files/styles/grid-3/public/project-images/Medium-Logo%20Color%20with%20padding.png)](https://www.drupal.org/project/varbase)

## Varbase: The Ultimate Drupal 8 CMS Starter Kit (Bootstrap Ready)

The powerful Drupal distribution for faster development, with editor experience
in mind. Brought to you by [Vardot](https://www.vardot.com/).

Varbase is an enhanced Drupal distribution with a lot of necessities.
Necessities are all the modules, features, configurations that we include
in every project.


## It's made with the following benefits in mind:

* Speeds up development.
* Offers standardized configuration and best-practices.
* Comes with a lot of needed functionalities/modules for every-day Drupal site.
* [Tested, tested, and tested.](https://travis-ci.org/Vardot/varbase/builds)

Starting a new project? Consider Varbase for Drupal 8.
Installing Varbase 8.x-5.x comes with several extra automated installation
steps, to take full advantage of Varbase, other than the Drupal 8 installation
instructions.

# Install with Composer

To install the most recent stable release of Varbase 8.5.x run this command:
```
composer create-project Vardot/varbase-project:8.5.4 PROJECT_DIR_NAME --no-dev --no-interaction
```

To install the dev version of Varbase 8.5.x run this command:
```
composer create-project vardot/varbase-project:8.5.x-dev PROJECT_DIR_NAME --stability dev --no-interaction
```

## [Create a new Vartheme sub theme for a project](https://github.com/Vardot/varbase/tree/8.x-5.x/scripts/README.md)

## [Automated Functional Testing](https://github.com/Vardot/varbase/blob/8.x-5.x/tests/README.md)

## [Varbase Gherkin features](https://github.com/Vardot/varbase/blob/8.x-5.x/tests/features/varbase/README.md)

## [Varbase 8.5.x Developer Guide](https://docs.varbase.vardot.com)

## [CHANGELOG for Varbase](https://github.com/Vardot/varbase/blob/8.x-5.x/CHANGELOG.md)

## [General instructions on how to update Varbase](https://github.com/Vardot/varbase/blob/8.x-5.x/UPDATE.md)
